@@ -1,7 +1,9 @@
 import re
 
-from databricks_cli.sdk import ApiClient
 import databricks_cli.sdk.service as services
+from databricks_cli.sdk import ApiClient
+
+___all__ = ["DatabricksAPI"]
 
 
 def camel_to_snake(name):
@@ -9,7 +11,14 @@ def camel_to_snake(name):
     return re.sub("([a-z0-9])([A-Z])", r"\1_\2", s).lower()
 
 
-class DatabricksAPI(object):
+def _get_services():
+    for service_name, service in services.__dict__.items():
+        if "Service" in service_name:
+            camel_name = camel_to_snake(service_name.replace("Service", ""))
+            yield service_name, camel_name, service
+
+
+class DatabricksAPI:
     def __init__(self, **kwargs):
         if "host" in kwargs:
             if not kwargs["host"].startswith("https://"):
@@ -17,7 +26,5 @@ class DatabricksAPI(object):
 
         self.client = ApiClient(**kwargs)
 
-        for service_name, service in services.__dict__.items():
-            if "Service" in service_name:
-                name = camel_to_snake(service_name.replace("Service", ""))
-                setattr(self, name, service(self.client))
+        for _, camel_name, service in _get_services():
+            setattr(self, camel_name, service(self.client))
